@@ -8,6 +8,7 @@ our %Remote = (
     source  => 'http://www.triviaasylum.com/dilbert/diltriv.html',
     extract => sub {
         return
+            grep { $_ ne '_' }
             map { y!- '/!___ !; s/\.//g; split ' ', lc }
             $_[0] =~ m!<b>([^<]+)</b>!gm;
     },
@@ -82,3 +83,4 @@ traylor uncle_albert uncle_max uncle_ned upholsterygeist virginia
 waldo wally walter wendel wendy will willy wilson wilt_gandhi winston
 world_s_smartest_garbage_man yergi yorgi yugi yvonne zenox zimbu zoltar
 tex flashy petricia tim_zumph earl lefty sourpuss wendel_j_stone_iv
+vijay
